window.Gleam.initSearch([{"doc":"gleebor","title":"gleebor","content":"# GleeBOR\n\n### A CBOR ([RFC 8949](https://www.rfc-editor.org/rfc/rfc8949.html)) Library for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/gleebor)](https://hex.pm/packages/gleebor)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleebor/)\n\nCBOR is a self-describing standardized data format used for data interchange. It&#39;s\nefficient, generally pretty fast, and best of all: has high quality implementations in\nmany languages. This libraries goal is to add to the list of languages that have strong\nCBOR support!\n\n&gt; [!note] The `BitArray` syntax used throughout this library is currently unsupported by\n&gt; the JavaScript backend. Until this is fixed upstream, this library is only expected to\n&gt; work for BEAM backed applications.\n\n\n```sh\ngleam add gleebor\n```\n```gleam\nimport gleebor\nimport io\n\nfn read_my_bytes() {\n  // 0 major arg, 24 to signal the following byte is the payload value, 123 is an 8-bit\n  //number\n  &lt;&lt;0:3, 24:5, 123:8&gt;&gt;\n}\n\npub fn main() {\n  // Get your bytes somehow!\n  let bytes = read_my_bytes()\n\n  let assert Ok(number) = gleebor.decode_int(bytes)\n  io.debug(number) // =&gt; 123\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleebor&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Status\n\nThe following describes the current status for this library&#39;s progress.\n\n\n- [/] Decode\n  - [x] Ints\n  - [ ] Floats\n  - [x] Text Strings (Sized)\n  - [x] Bytes (sized)\n  - [x] Arrays (sized)\n  - [ ] Maps\n  - [ ] Tags\n  - [ ] Indefinite sequences\n- [ ] Encode\n  - [ ] Ints\n  - [ ] Floats\n  - [ ] Text Strings (Sized)\n  - [ ] Bytes (sized)\n  - [ ] Arrays (sized)\n  - [ ] Maps\n  - [ ] Tags\n  - [ ] Indefinite sequences\n\n\n","url":"index.html"},{"doc":"gleebor","title":"CborError","content":"pub type CborError {\n  PrematureEOF\n  InvalidMajorArg(Int)\n  IncorrectType(major_type: Int)\n  MalformedUTF8\n}\n\nPrematureEOF\n Indicates the input ended prematurely and decoding could not continue.\n\nInvalidMajorArg(Int)\n This indicates that the major type in the payload was one that is not\n valid according to the CBOR specification. See RFC 8949 section 3.\n\nIncorrectType(major_type: Int)\n Indicates the type decoded did not match the expected type.\nmajor_type\n&lt;p&gt;the major_type is the CBOR Section 3.1 Major Types indicator.&lt;/p&gt;\n\nMalformedUTF8\n\n\nSynonyms:\ngleebor.CborError\ngleebor CborError","url":"gleebor.html#CborError"},{"doc":"gleebor","title":"decode_bytes","content":"pub fn decode_bytes(\n  a: BitArray,\n) -&gt; Result(#(BitArray, BitArray), CborError)\n Decodes an array of bytes\nSynonyms:\ngleebor.decode_bytes\ngleebor decode_bytes","url":"gleebor.html#decode_bytes"},{"doc":"gleebor","title":"decode_int","content":"pub fn decode_int(\n  a: BitArray,\n) -&gt; Result(#(Int, BitArray), CborError)\n\nSynonyms:\ngleebor.decode_int\ngleebor decode_int","url":"gleebor.html#decode_int"},{"doc":"gleebor","title":"decode_list","content":"pub fn decode_list(\n  buffer a: BitArray,\n  with f: fn(BitArray) -&gt; Result(#(a, BitArray), CborError),\n) -&gt; Result(\n  Iterator(Result(#(a, BitArray), CborError)),\n  CborError,\n)\n Decodes a homogenous array or list of items from BitArray using the\n provided callback function.\nSynonyms:\ngleebor.decode_list\ngleebor decode_list","url":"gleebor.html#decode_list"},{"doc":"gleebor","title":"decode_string","content":"pub fn decode_string(\n  a: BitArray,\n) -&gt; Result(#(String, BitArray), CborError)\n\nSynonyms:\ngleebor.decode_string\ngleebor decode_string","url":"gleebor.html#decode_string"},{"doc":"gleebor","title":"gleebor","content":"","url":"gleebor.html"}]);